==> base-domain-0.0.3-20170112.031550-61-sources.jar: com/thebeastshop/scm/vo/lottery/LotteryActivityRecordVO.java <==
package com.thebeastshop.scm.vo.lottery;

import java.util.Date;

import pers.richard.ormybatis.domain.core.AbstractDomain;

/**
 * 中奖信息VO
 * @author donghui
 */
public class LotteryActivityRecordVO extends AbstractDomain {
	private Integer lotteryActivityPrizeRecordId;//抽奖记录ID
	private Integer memberId;//中奖人
	private String memberNickName;//中奖人昵称
	private String awardName;//奖项名(如:一等奖项)
	private String awardContent;//中奖后展示文案
	private String type;//中奖品的类型(积分:"POINT", 优惠券:"COUPON", 商品:"PRODUCT")
	private String typeNum;//积分数量或者优惠券ID or SKUCODE
	private String couponSampleName;//优惠券名(if type = "COUPON" ,反之为null)
	private Date createTime;//抽奖时间
	
	public LotteryActivityRecordVO(){
	}
	
	public Integer getLotteryActivityPrizeRecordId() {
		return lotteryActivityPrizeRecordId;
	}

	public void setLotteryActivityPrizeRecordId(Integer lotteryActivityPrizeRecordId) {
		this.lotteryActivityPrizeRecordId = lotteryActivityPrizeRecordId;
	}

	public Integer getMemberId() {
		return memberId;
	}

	public void setMemberId(Integer memberId) {
		this.memberId = memberId;
	}

	public String getMemberNickName() {
		return memberNickName;
	}

	public void setMemberNickName(String memberNickName) {
		this.memberNickName = memberNickName;
	}

	public String getAwardName() {
		return awardName;
	}

	public void setAwardName(String awardName) {
		this.awardName = awardName;
	}

	public String getAwardContent() {
		return awardContent;
	}

	public void setAwardContent(String awardContent) {
		this.awardContent = awardContent;
	}

	public String getType() {
		return type;
	}

	public void setType(String type) {
		this.type = type;
	}

	public String getTypeNum() {
		return typeNum;
	}

	public void setTypeNum(String typeNum) {
		this.typeNum = typeNum;
	}

	public String getCouponSampleName() {
		return couponSampleName;
	}

	public void setCouponSampleName(String couponSampleName) {
		this.couponSampleName = couponSampleName;
	}
	public Date getCreateTime() {
		return createTime;
	}

	public void setCreateTime(Date createTime) {
		this.createTime = createTime;
	}

}

==> base-domain-0.0.3-20170215.062859-90-sources.jar: com/thebeastshop/scm/vo/lottery/LotteryActivityRecordVO.java <==
package com.thebeastshop.scm.vo.lottery;

import java.util.Date;

import com.thebeastshop.scm.vo.interest.InterestGetVO;

import pers.richard.ormybatis.domain.core.AbstractDomain;

/**
 * 中奖信息VO
 * @author donghui
 */
public class LotteryActivityRecordVO extends AbstractDomain {
	private Integer lotteryActivityPrizeRecordId;//抽奖记录ID
	private Integer memberId;//中奖人
	private String memberNickName;//中奖人昵称
	private String awardName;//奖项名(如:一等奖项)
	private String awardContent;//中奖后展示文案
	private String type;//中奖品的类型(积分:"POINT", 优惠券:"COUPON", 商品:"PRODUCT")
	private String typeNum;//积分数量或者优惠券ID or SKUCODE
	private String couponSampleName;//优惠券名(if type = "COUPON" ,反之为null)
	private Date createTime;//抽奖时间
	
	private InterestGetVO interestGetVO;//权益信息(if type = "PRODUCT" ,反之为null)
	
	public LotteryActivityRecordVO(){
	}
	
	public Integer getLotteryActivityPrizeRecordId() {
		return lotteryActivityPrizeRecordId;
	}

	public void setLotteryActivityPrizeRecordId(Integer lotteryActivityPrizeRecordId) {
		this.lotteryActivityPrizeRecordId = lotteryActivityPrizeRecordId;
	}

	public Integer getMemberId() {
		return memberId;
	}

	public void setMemberId(Integer memberId) {
		this.memberId = memberId;
	}

	public String getMemberNickName() {
		return memberNickName;
	}

	public void setMemberNickName(String memberNickName) {
		this.memberNickName = memberNickName;
	}

	public String getAwardName() {
		return awardName;
	}

	public void setAwardName(String awardName) {
		this.awardName = awardName;
	}

	public String getAwardContent() {
		return awardContent;
	}

	public void setAwardContent(String awardContent) {
		this.awardContent = awardContent;
	}

	public String getType() {
		return type;
	}

	public void setType(String type) {
		this.type = type;
	}

	public String getTypeNum() {
		return typeNum;
	}

	public void setTypeNum(String typeNum) {
		this.typeNum = typeNum;
	}

	public String getCouponSampleName() {
		return couponSampleName;
	}

	public void setCouponSampleName(String couponSampleName) {
		this.couponSampleName = couponSampleName;
	}
	public Date getCreateTime() {
		return createTime;
	}

	public void setCreateTime(Date createTime) {
		this.createTime = createTime;
	}
	public InterestGetVO getInterestGetVO() {
		return interestGetVO;
	}

	public void setInterestGetVO(InterestGetVO interestGetVO) {
		this.interestGetVO = interestGetVO;
	}
}
